@@ -32,7 +32,7 @@ def check_common_error(error_handler, function, args = ()):
 
     """
     # todo: import here to avoid circular dependency issue
-    import duplicity.path as path
+    from duplicity import path
 
     try: return function(*args)
     #except (EnvironmentError, SkipFileException, DSRPPermError,
@@ -55,12 +55,12 @@ def check_common_error(error_handler, function, args = ()):
 def listpath(path):
     """Like path.listdir() but return [] if error, and sort results"""
     def error_handler(exc):
-        log.Log(_("Error listing directory %s") % path.name, 2)
+        log.Warn(_("Error listing directory %s") % path.name)
         return []
     dir_listing = check_common_error(error_handler, path.listdir)
     dir_listing.sort()
     return dir_listing
 
-import duplicity.librsync as librsync
-import duplicity.log as log
+from duplicity import librsync
+from duplicity import log
 
